@@ -16,10 +16,11 @@ def dump_compiler(di):
     die = next(di.iter_CUs()).get_top_DIE()
     print(die.attributes['DW_AT_producer'].value.decode('UTF-8'))
 
+test_file("samples\\sles_507.88")
 #test_tree_for("\\\\sandbox\\seva\\webdata\\clarify\\derived", dump_compiler)    
 #test_tree_for("\\\\mac\\seva\\quincy", dump_compiler)
 
-test_tree("samples")
+#test_tree("samples")
 
 def f(di):
     CUs = [cu for cu in di.iter_CUs()]
@@ -31,7 +32,7 @@ def f(di):
 
 
 
-test_file('\\\\sandbox\\seva\\webdata\\clarify\\derived\\An-3.20.0-y-ARMv7\\libyarxi.so')
+#test_file('\\\\sandbox\\seva\\webdata\\clarify\\derived\\An-3.20.0-y-ARMv7\\libyarxi.so')
 #test_file('\\\\mac\\seva\\quincy\\4.69.8\\YarxiMin.app.dSYM')
 #test_tree('\\\\mac\\seva\\quincy')
 #test_file('E:\\Seva\\Projects\\AnYarxi_3.43.5\\LibYarxi\\build\\intermediates\\ndkBuild\\yarxiRelease\\obj\\local\\x86\\libfakejipad.so')
